==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/AutoApprove.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Auto approve pull requests that meet a criteria.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.738Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoApprove")
public class AutoApprove extends io.github.cdklabs.projen.Component {

    protected AutoApprove(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AutoApprove(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AutoApprove(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.AutoApproveOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getLabel() {
        return software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.AutoApprove}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.AutoApprove> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private final io.github.cdklabs.projen.github.AutoApproveOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
            this.options = new io.github.cdklabs.projen.github.AutoApproveOptions.Builder();
        }

        /**
         * (experimental) A GitHub secret name which contains a GitHub Access Token with write permissions for the `pull_request` scope.
         * <p>
         * This token is used to approve pull requests.
         * <p>
         * Github forbids an identity to approve its own pull request.
         * If your project produces automated pull requests using the Github default token -
         * {&#64;link https://docs.github.com/en/actions/reference/authentication-in-a-workflow <code>GITHUB_TOKEN</code> }
         * <p>
         * <ul>
         * <li>that you would like auto approved, such as when using the <code>depsUpgrade</code> property in
         * <code>NodeProjectOptions</code>, then you must use a different token here.</li>
         * </ul>
         * <p>
         * @return {@code this}
         * @param secret A GitHub secret name which contains a GitHub Access Token with write permissions for the `pull_request` scope. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secret(final java.lang.String secret) {
            this.options.secret(secret);
            return this;
        }

        /**
         * (experimental) Only pull requests authored by these Github usernames will be auto-approved.
         * <p>
         * Default: ['github-bot']
         * <p>
         * @return {@code this}
         * @param allowedUsernames Only pull requests authored by these Github usernames will be auto-approved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder allowedUsernames(final java.util.List<java.lang.String> allowedUsernames) {
            this.options.allowedUsernames(allowedUsernames);
            return this;
        }

        /**
         * (experimental) Only pull requests with this label will be auto-approved.
         * <p>
         * Default: 'auto-approve'
         * <p>
         * @return {@code this}
         * @param label Only pull requests with this label will be auto-approved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder label(final java.lang.String label) {
            this.options.label(label);
            return this;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options.runsOn(runsOn);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.github.AutoApprove}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.AutoApprove build() {
            return new io.github.cdklabs.projen.github.AutoApprove(
                this.github,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/AutoApprove.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Auto approve pull requests that meet a criteria.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.413Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoApprove")
public class AutoApprove extends io.github.cdklabs.projen.Component {

    protected AutoApprove(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AutoApprove(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AutoApprove(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.AutoApproveOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), options });
    }

    /**
     * @param github This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public AutoApprove(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getLabel() {
        return software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.AutoApprove}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.AutoApprove> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private io.github.cdklabs.projen.github.AutoApproveOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
        }

        /**
         * (experimental) Only pull requests authored by these Github usernames will be auto-approved.
         * <p>
         * Default: ['github-bot']
         * <p>
         * @return {@code this}
         * @param allowedUsernames Only pull requests authored by these Github usernames will be auto-approved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder allowedUsernames(final java.util.List<java.lang.String> allowedUsernames) {
            this.options().allowedUsernames(allowedUsernames);
            return this;
        }

        /**
         * (experimental) Only pull requests with this label will be auto-approved.
         * <p>
         * Default: 'auto-approve'
         * <p>
         * @return {@code this}
         * @param label Only pull requests with this label will be auto-approved. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder label(final java.lang.String label) {
            this.options().label(label);
            return this;
        }

        /**
         * (experimental) Github Runner selection labels.
         * <p>
         * Default: ["ubuntu-latest"]
         * <p>
         * @return {@code this}
         * @param runsOn Github Runner selection labels. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(final java.util.List<java.lang.String> runsOn) {
            this.options().runsOn(runsOn);
            return this;
        }

        /**
         * (experimental) Github Runner Group selection options.
         * <p>
         * @return {@code this}
         * @param runsOnGroup Github Runner Group selection options. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.options().runsOnGroup(runsOnGroup);
            return this;
        }

        /**
         * (experimental) A GitHub secret name which contains a GitHub Access Token with write permissions for the <code>pull_request</code> scope.
         * <p>
         * This token is used to approve pull requests.
         * Github forbids an identity to approve its own pull request.
         * If your project produces automated pull requests using the Github default token -
         * {@link https://docs.github.com/en/actions/reference/authentication-in-a-workflow `GITHUB_TOKEN` }
         * * that you would like auto approved, such as when using the `depsUpgrade` property in
         *   `NodeProjectOptions`, then you must use a different token here.
         * <p>
         * Default: "GITHUB_TOKEN"
         * <p>
         * @return {@code this}
         * @param secret A GitHub secret name which contains a GitHub Access Token with write permissions for the <code>pull_request</code> scope. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secret(final java.lang.String secret) {
            this.options().secret(secret);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.github.AutoApprove}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.AutoApprove build() {
            return new io.github.cdklabs.projen.github.AutoApprove(
                this.github,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.AutoApproveOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.AutoApproveOptions.Builder();
            }
            return this.options;
        }
    }
}
